==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectMapply_binary.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectmapply_binary_h
#define objectmapply_binary_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_mapply_binary_enumeration_name_addm,
  adms_mapply_binary_enumeration_name_addp,
  adms_mapply_binary_enumeration_name_and,
  adms_mapply_binary_enumeration_name_bw_and,
  adms_mapply_binary_enumeration_name_bw_equl,
  adms_mapply_binary_enumeration_name_bw_equr,
  adms_mapply_binary_enumeration_name_bw_or,
  adms_mapply_binary_enumeration_name_bw_xor,
  adms_mapply_binary_enumeration_name_equ,
  adms_mapply_binary_enumeration_name_gt,
  adms_mapply_binary_enumeration_name_gt_equ,
  adms_mapply_binary_enumeration_name_lt,
  adms_mapply_binary_enumeration_name_lt_equ,
  adms_mapply_binary_enumeration_name_multdiv,
  adms_mapply_binary_enumeration_name_multmod,
  adms_mapply_binary_enumeration_name_multtime,
  adms_mapply_binary_enumeration_name_notequ,
  adms_mapply_binary_enumeration_name_or,
  adms_mapply_binary_enumeration_name_shiftl,
  adms_mapply_binary_enumeration_name_shiftr
} e_mapply_binary_name;
win32_interface char* adms_mapply_binary_tostring_name_impl (p_admsttransform myadmsttransform,e_mapply_binary_name e);
win32_interface e_mapply_binary_name adms_mapply_binary_fromstring_name_impl (p_admsttransform myadmsttransform,char*token);
struct s_mapply_binary {
  t_subexpression _subexpression;
  e_mapply_binary_name _name;
  int _name_isdefault : 1;
  gpointer _arg1;
  int _arg1_isdefault : 1;
  gpointer _arg2;
  int _arg2_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_mapply_binary_getuid (p_mapply_binary mymapply_binary);
win32_interface gboolean adms_mapply_binary_cmp (p_mapply_binary mymapply_binary,p_mapply_binary refmapply_binary);
win32_interface p_mapply_binary adms_mapply_binary_new_1 (e_mapply_binary_name myname,gpointer myarg1,gpointer myarg2);
#define adms_mapply_binary_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_mapply_binary_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_mapply_binary_new_impl (p_adms arguments[]);
win32_interface p_mapply_binary adms_mapply_binary_impl (void* member);
#define adms_mapply_binary(member) ((p_mapply_binary) (member))
#define adms_mapply_binary_new adms_mapply_binary_new_1
#define adms_mapply_binary_isdefault_name(mapply_binary) (adms_mapply_binary(mapply_binary)->_name_isdefault)
#define adms_mapply_binary_valueof_name(mapply_binary) (adms_mapply_binary(mapply_binary)->_name)
#define adms_mapply_binary_isdefault_arg1(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg1_isdefault)
#define adms_mapply_binary_valueof_arg1(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg1)
#define adms_mapply_binary_isdefault_arg2(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg2_isdefault)
#define adms_mapply_binary_valueof_arg2(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg2)
#define adms_mapply_binary_valueof_subexpression(mapply_binary) ((p_subexpression)mapply_binary)
#define adms_mapply_binary_valueof_math(mapply_binary) ((p_math)mapply_binary)
#define adms_mapply_binary_valueof_adms(mapply_binary) ((p_adms)mapply_binary)
#define adms_mapply_binary_valueto_name(a,b) ((p_mapply_binary)a)->_name=(b)
win32_interface void adms_mapply_binary_valueto_name_impl (p_mapply_binary mymapply_binary,e_mapply_binary_name _name);
#define adms_mapply_binary_valueto_arg1(a,b) ((p_mapply_binary)a)->_arg1=(b)
win32_interface void adms_mapply_binary_valueto_arg1_impl (p_mapply_binary mymapply_binary,gpointer _arg1);
#define adms_mapply_binary_valueto_arg2(a,b) ((p_mapply_binary)a)->_arg2=(b)
win32_interface void adms_mapply_binary_valueto_arg2_impl (p_mapply_binary mymapply_binary,gpointer _arg2);
#endif /* objectmapply_binary_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectMapply_binary.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectmapply_binary_h
#define objectmapply_binary_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_mapply_binary_enumeration_name_addm,
  adms_mapply_binary_enumeration_name_addp,
  adms_mapply_binary_enumeration_name_and,
  adms_mapply_binary_enumeration_name_bw_and,
  adms_mapply_binary_enumeration_name_bw_equl,
  adms_mapply_binary_enumeration_name_bw_equr,
  adms_mapply_binary_enumeration_name_bw_or,
  adms_mapply_binary_enumeration_name_bw_xor,
  adms_mapply_binary_enumeration_name_equ,
  adms_mapply_binary_enumeration_name_gt,
  adms_mapply_binary_enumeration_name_gt_equ,
  adms_mapply_binary_enumeration_name_lt,
  adms_mapply_binary_enumeration_name_lt_equ,
  adms_mapply_binary_enumeration_name_multdiv,
  adms_mapply_binary_enumeration_name_multmod,
  adms_mapply_binary_enumeration_name_multtime,
  adms_mapply_binary_enumeration_name_notequ,
  adms_mapply_binary_enumeration_name_or,
  adms_mapply_binary_enumeration_name_shiftl,
  adms_mapply_binary_enumeration_name_shiftr
} e_mapply_binary_name;
win32_interface char* adms_mapply_binary_tostring_name_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_mapply_binary_name adms_mapply_binary_fromstring_name_impl (p_admsttransform myadmsttransform,char*token);
struct s_mapply_binary {
  t_subexpression _subexpression;
  p_enumeration _name;
  int _name_isdefault : 1;
  p_adms _arg1;
  int _arg1_isdefault : 1;
  p_adms _arg2;
  int _arg2_isdefault : 1;
};
#include <admsObject/objectEnumeration.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_mapply_binary_uid (p_mapply_binary mymapply_binary);
win32_interface int adms_mapply_binary_cmp (p_mapply_binary mymapply_binary,p_mapply_binary refmapply_binary);
win32_interface p_mapply_binary adms_mapply_binary_new(p_enumeration myname,p_adms myarg1,p_adms myarg2);
win32_interface p_adms adms_mapply_binary_new_impl (p_adms arguments[]);
#define adms_mapply_binary(member) ((p_mapply_binary) (member))
#define adms_mapply_binary_isdefault_name(mapply_binary) (adms_mapply_binary(mapply_binary)->_name_isdefault)
#define adms_mapply_binary_valueof_name(mapply_binary) (adms_mapply_binary(mapply_binary)->_name)
#define adms_mapply_binary_isdefault_arg1(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg1_isdefault)
#define adms_mapply_binary_valueof_arg1(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg1)
#define adms_mapply_binary_isdefault_arg2(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg2_isdefault)
#define adms_mapply_binary_valueof_arg2(mapply_binary) (adms_mapply_binary(mapply_binary)->_arg2)
#define adms_mapply_binary_valueof_subexpression(mapply_binary) ((p_subexpression)mapply_binary)
#define adms_mapply_binary_valueof_math(mapply_binary) ((p_math)mapply_binary)
#define adms_mapply_binary_valueof_adms(mapply_binary) ((p_adms)mapply_binary)
win32_interface inline void adms_mapply_binary_valueto_name (p_mapply_binary mymapply_binary,p_enumeration _name);
win32_interface inline void adms_mapply_binary_valueto_arg1 (p_mapply_binary mymapply_binary,p_adms _arg1);
win32_interface inline void adms_mapply_binary_valueto_arg2 (p_mapply_binary mymapply_binary,p_adms _arg2);
win32_interface inline void adms_mapply_binary_free(p_mapply_binary mymapply_binary);
#endif /* objectmapply_binary_h */
